@@ -57,9 +57,15 @@ plot.Rcpp_FONSEParameter <- function(x, what = "Mutation", samples = 100, mixtur
   plotParameterObject(x, what = what, samples=samples,mixture.name = mixture.name, with.ci=with.ci, ...)
 }
 
+plot.Rcpp_PAParameter <- function(x, what = "Mutation", samples = 100, mixture.name = NULL, with.ci = TRUE, ...)
+{
+  #to_plot = ifelse(what == "Alpha", "Mutation", "Selection")
+  plotParameterObject(x, what = what, samples=samples,mixture.name = mixture.name, with.ci=with.ci, ...)
+  #plotPA(x)
+}
+
 ### NOT EXPOSED
 plotParameterObject <- function(x, what = "Mutation", samples = 100, mixture.name = NULL, with.ci = TRUE, ...){
-  
   numMixtures <- x$numMixtures
   means <- data.frame(matrix(0,ncol=numMixtures,nrow=40))
   sd.values <- data.frame(matrix(0,ncol=numMixtures*2,nrow=40))
@@ -111,18 +117,20 @@ plotParameterObject <- function(x, what = "Mutation", samples = 100, mixture.nam
           text(x = 0.5, y = 0.5, mixture.name[i], 
                cex = 1.6, col = "black")
         }
-      } else if(i<j){
-          if(with.ci){
-            plot(means[,j],means[,i],ann=FALSE,xlim=range(cbind(sd.values[,j],sd.values[,j+numMixtures])),ylim=range(cbind(sd.values[,i],sd.values[,i+numMixtures])))
-            upper.panel.plot(means[,j],means[,i],sd.x=cbind(sd.values[,j],sd.values[,j+numMixtures]),sd.y=cbind(sd.values[,i],sd.values[,i+numMixtures]))
-          } else{
-            plot(means[,j],means[,i],ann=FALSE,xlim=range(means[,j]),ylim=range(means[,i]))
-            upper.panel.plot(means[,j],means[,i])
-          }
+      }
+      else if (i < j){
+        if(with.ci){
+          plot(means[,j],means[,i],ann=FALSE,xlim=range(cbind(sd.values[,j],sd.values[,j+numMixtures])),ylim=range(cbind(sd.values[,i],sd.values[,i+numMixtures])))
+          upper.panel.plot(means[,j],means[,i],sd.x=cbind(sd.values[,j],sd.values[,j+numMixtures]),sd.y=cbind(sd.values[,i],sd.values[,i+numMixtures]))
+          #confidenceInterval.plot(x = means[,j],y = mean[,i], sd.x=sd.values[,j],sd.y=sd.values[,i])
+        } else{
+          plot(means[,j],means[,i],ann=FALSE,xlim=range(means[,j]),ylim=range(means[,i]))
+          upper.panel.plot(means[,j],means[,i])
         }
       }
     }
   }
+}
 
 
 
@@ -175,7 +183,7 @@ upper.panel.plot <- function(x, y, sd.x=NULL, sd.y=NULL, ...){
   intercept <- round(summary(lm.line)$coefficients[1], 3)
   t <- (slope - 1)/std.error
   
-  if(t > qt(1-(0.05/2), lm.line$df.residual - 1) || t < qt(0.05/2,lm.line$df.residual-1)){
+  if((t > qt(1-(0.05/2), lm.line$df.residual - 1))||(t < qt((0.05/2),lm.line$df.residual-1))){
     eq <- paste0("y = ", sprintf("%.3f", intercept), " + ", sprintf("%.3f", slope), "x *")
     text(xlim[1] + width * 0.01, ylim[2] - height * 0.2, eq, pos = 4, cex = 1.5)
   }else{
@@ -214,17 +222,17 @@ confidenceInterval.plot <- function(x, y, sd.x=NULL, sd.y=NULL, ...){
     epsilon <- range(y, na.rm = T) * 0.1
     segments(x.low, y, x.up, y, ...)
   }  
-  
-  lm.line <- lm(y~x, na.action = "na.exclude") 
-  
+
+  lm.line <- lm(y~x, na.action = "na.exclude")
+
   b <- lm.line$coef[2]
-  
+
   xlim <- range(x, na.rm = T)
   ylim <- range(y, na.rm = T)
-  
+
   width <- xlim[2] - xlim[1]
   height <- ylim[2] - ylim[1]
-  
+
   std.error <- summary(lm.line)$coefficients[4]
   slope <- round(summary(lm.line)$coefficients[2], 3)
   intercept <- round(summary(lm.line)$coefficients[1], 3)
@@ -232,6 +240,66 @@ confidenceInterval.plot <- function(x, y, sd.x=NULL, sd.y=NULL, ...){
 }
 
 
+plotPA <- function(parameter,genome,samples=100,mixture=1){
+    #cat("hello")
+    cat <- mixture
+trace <- parameter$getTraceObject()
+proposal <- FALSE
+alphaList <- numeric (61)
+lambdaPrimeList <- numeric (61)
+waitingTimes <- numeric(61)
+alpha.ci <- matrix(0, ncol=2, nrow=61)
+lambdaPrime.ci <- matrix(0, ncol=2, nrow=61)
+psiList <- numeric(length(genome))
+ids <- numeric(length(genome))
+codonList <- codons()
+for (i in 1:61)
+{
+  codon <- codonList[i]
+  alphaList[i] <- parameter$getCodonSpecificPosteriorMean(cat, samples * 0.5, codon, 0, FALSE)
+  alphaTrace <- trace$getCodonSpecificParameterTraceByMixtureElementForCodon(1, codon, 0, FALSE)
+  alpha.ci[i,] <- quantile(alphaTrace[(samples * 0.5):samples], probs = c(0.025,0.975))
+  
+  
+  lambdaPrimeList[i] <- parameter$getCodonSpecificPosteriorMean(cat, samples * 0.5, codon, 1, FALSE)
+  lambdaPrimeTrace <- trace$getCodonSpecificParameterTraceByMixtureElementForCodon(1, codon, 1, FALSE)
+  lambdaPrime.ci[i,] <- quantile(lambdaPrimeTrace[(samples * 0.5):samples], probs = c(0.025,0.975))
+  waitingTimes[i] <- alphaList[i] * lambdaPrimeList[i]
+}
+
+waitRates <- numeric(61)
+for (i in 1:61) {
+  waitRates[i] <- (1.0/waitingTimes[i])
+}
+
+
+for (geneIndex in 1:length(genome)) {
+  psiList[geneIndex] <- parameter$getSynthesisRatePosteriorMeanForGene(samples * 0.5, geneIndex, 1)
+}
+
+for (i in 1:length(genome))
+{
+  g <- genome$getGeneByIndex(i, FALSE)
+  ids[i] <- g$id
+}
+
+#Plot confidence intervals for alpha and lambda prime
+plot(NULL, NULL, xlim=range(1:61, na.rm = T), ylim=range(alpha.ci), 
+     main = "Confidence Intervals for Alpha Parameter", xlab = "Codons", 
+     ylab = "Estimated values", axes=F) 
+confidenceInterval.plot(x = 1:61, y = alphaList, sd.y = alpha.ci)
+axis(2)
+axis(1, tck = 0.02, labels = codonList[1:61], at=1:61, las=2, cex.axis=.6)
+
+plot(NULL, NULL, xlim=range(1:61, na.rm = T), ylim=range(lambdaPrime.ci), 
+     main = "Confidence Intervals for LambdaPrime Parameter", xlab = "Codons", 
+     ylab = "Estimated values", axes=F) 
+confidenceInterval.plot(x = 1:61, y = lambdaPrimeList, sd.y = lambdaPrime.ci)
+axis(2)
+axis(1, tck = 0.02, labels = codonList[1:61], at=1:61, las=2, cex.axis=.6)
+#dev.off()
+}
+
 #' Plots ACF for codon specific parameter traces
 #' 
 #' @param parameter object of class Parameter
